Core type system: LogicalType, PhysicalType, Value, InternalID, date/time types.
Structs
- Date
- Date representation (days since epoch).
- InternalID
- A 4-byte aligned, 8-byte internal node/rel identifier.
- Interval
- Interval (duration).
- Timestamp
- Timestamp representation (microseconds since epoch).
- TimestampTZ
- Timestamp with timezone.
Enums
- Logical
TypeID - Logical type identifiers for Akar’s type system.
- Physical
TypeID - Physical type identifiers for in-memory representation.
- Value
- A Akar value — the runtime representation of any data type.
Functions
- extract_
f64_ list - Extract a
Vec<f64>from aValue(expectsValue::Listof numbers). - physical_
type_ from_ logical - Map a LogicalTypeID to its corresponding PhysicalTypeID.
- pk_
value_ to_ string - Render a
Valueas the canonical string key used by hash indexes on primary keys. - value_
to_ csv_ string - Render a
Valueas a CSV cell:Nullbecomes an empty field, anything else uses the canonical scalar rendering (pk_value_to_string).